lambdafunction
==============

Lambda event
------------

.. autoclass:: awsmate.lambdafunction.LambdaEvent

Lambda event related errors
---------------------------

.. autoexception:: awsmate.lambdafunction.AwsEventSpecificationError
